Release History
===============

Dev
---
**Title**

- \[List of changes\]

0.0.1-alpha.3 (16 Feb 2020)
---------------------------

**Improvements**

- Added Example to use it.
- Added new classes to start developing first phase work

**Note**

- Not a usable library yet still in initial development phase to make it minimal project requirement


Next
----
- Automate the History tracking
- Adding Contribution guide
- Adding new classes for minimal functionality support
